EXPORTS
	??0TContactListsWrapper@@QAE@ABVMDesC16Array@@@Z @ 1 NONAME ; TContactListsWrapper::TContactListsWrapper(class MDesC16Array const &)
	??0TContactListsWrapper@@QAE@XZ @ 2 NONAME ; TContactListsWrapper::TContactListsWrapper(void)
	??0TMultiPecListWrapper@@QAE@XZ @ 3 NONAME ; TMultiPecListWrapper::TMultiPecListWrapper(void)
	??0TOneContactListWrapper@@QAE@ABVMPEngContactList2@@@Z @ 4 NONAME ; TOneContactListWrapper::TOneContactListWrapper(class MPEngContactList2 const &)
	??0TOneDesWrapper@@QAE@ABVTDesC16@@@Z @ 5 NONAME ; TOneDesWrapper::TOneDesWrapper(class TDesC16 const &)
	??0TTrackedPresenceIds@@QAE@XZ @ 6 NONAME ; TTrackedPresenceIds::TTrackedPresenceIds(void)
	?Close@TMultiPecListWrapper@@QAEXXZ @ 7 NONAME ; void TMultiPecListWrapper::Close(void)
	?Close@TTrackedPresenceIds@@QAEXXZ @ 8 NONAME ; void TTrackedPresenceIds::Close(void)
	?InitializeLC@TMultiPecListWrapper@@QAEXAAVMDesC16Array@@AAVCPEngContactListStore2@@@Z @ 9 NONAME ; void TMultiPecListWrapper::InitializeLC(class MDesC16Array &, class CPEngContactListStore2 &)
	?InitializeLC@TTrackedPresenceIds@@QAEXAAVCPEngTrackedPresenceIDs2@@@Z @ 10 NONAME ; void TTrackedPresenceIds::InitializeLC(class CPEngTrackedPresenceIDs2 &)
	?InstanceL@CAPresenceManager@@SAPAVMCAPresence@@PAVMCASettings@@@Z @ 11 NONAME ; class MCAPresence * CAPresenceManager::InstanceL(class MCASettings *)
	?MdcaCount@TContactListsWrapper@@UBEHXZ @ 12 NONAME ; int TContactListsWrapper::MdcaCount(void) const
	?MdcaCount@TMultiPecListWrapper@@UBEHXZ @ 13 NONAME ; int TMultiPecListWrapper::MdcaCount(void) const
	?MdcaCount@TOneContactListWrapper@@UBEHXZ @ 14 NONAME ; int TOneContactListWrapper::MdcaCount(void) const
	?MdcaCount@TOneDesWrapper@@UBEHXZ @ 15 NONAME ; int TOneDesWrapper::MdcaCount(void) const
	?MdcaCount@TTrackedPresenceIds@@UBEHXZ @ 16 NONAME ; int TTrackedPresenceIds::MdcaCount(void) const
	?MdcaPoint@TContactListsWrapper@@UBE?AVTPtrC16@@H@Z @ 17 NONAME ; class TPtrC16 TContactListsWrapper::MdcaPoint(int) const
	?MdcaPoint@TMultiPecListWrapper@@UBE?AVTPtrC16@@H@Z @ 18 NONAME ; class TPtrC16 TMultiPecListWrapper::MdcaPoint(int) const
	?MdcaPoint@TOneContactListWrapper@@UBE?AVTPtrC16@@H@Z @ 19 NONAME ; class TPtrC16 TOneContactListWrapper::MdcaPoint(int) const
	?MdcaPoint@TOneDesWrapper@@UBE?AVTPtrC16@@H@Z @ 20 NONAME ; class TPtrC16 TOneDesWrapper::MdcaPoint(int) const
	?MdcaPoint@TTrackedPresenceIds@@UBE?AVTPtrC16@@H@Z @ 21 NONAME ; class TPtrC16 TTrackedPresenceIds::MdcaPoint(int) const
	?Release@CAPresenceManager@@SAXXZ @ 22 NONAME ; void CAPresenceManager::Release(void)

